@@ -277,8 +277,8 @@ ProcVidModeGetModeLine(ClientPtr client)
 
     /*
      * Older servers sometimes had server privates that the VidMode
-     * extention made available. So to be compatiable pretend that
-     * there are no server privates to pass to the client
+     * extension made available. So to be compatible pretend that
+     * there are no server privates to pass to the client.
      */
     rep.privsize = 0;
 
@@ -808,6 +808,8 @@ ProcVidModeModModeLine(ClientPtr client)
         return BadValue;
 
     modetmp = VidModeCreateMode();
+    if (modetmp == NULL)
+        return BadAlloc;
     VidModeCopyMode(mode, modetmp);
 
     VidModeSetModeValue(modetmp, VIDMODE_H_DISPLAY, stuff->hdisplay);
@@ -951,6 +953,8 @@ ProcVidModeValidateModeLine(ClientPtr client)
         return BadValue;
 
     modetmp = VidModeCreateMode();
+    if (modetmp == NULL)
+        return BadAlloc;
     VidModeCopyMode(mode, modetmp);
 
     VidModeSetModeValue(modetmp, VIDMODE_H_DISPLAY, stuff->hdisplay);
@@ -1703,7 +1707,7 @@ ProcVidModeDispatch(ClientPtr client)
     }
 }
 
-static int
+static int _X_COLD
 SProcVidModeQueryVersion(ClientPtr client)
 {
     REQUEST(xXF86VidModeQueryVersionReq);
@@ -1711,7 +1715,7 @@ SProcVidModeQueryVersion(ClientPtr client)
     return ProcVidModeQueryVersion(client);
 }
 
-static int
+static int _X_COLD
 SProcVidModeGetModeLine(ClientPtr client)
 {
     REQUEST(xXF86VidModeGetModeLineReq);
@@ -1721,7 +1725,7 @@ SProcVidModeGetModeLine(ClientPtr client)
     return ProcVidModeGetModeLine(client);
 }
 
-static int
+static int _X_COLD
 SProcVidModeGetAllModeLines(ClientPtr client)
 {
     REQUEST(xXF86VidModeGetAllModeLinesReq);
@@ -1731,7 +1735,7 @@ SProcVidModeGetAllModeLines(ClientPtr client)
     return ProcVidModeGetAllModeLines(client);
 }
 
-static int
+static int _X_COLD
 SProcVidModeAddModeLine(ClientPtr client)
 {
     xXF86OldVidModeAddModeLineReq *oldstuff =
@@ -1776,7 +1780,7 @@ SProcVidModeAddModeLine(ClientPtr client)
     return ProcVidModeAddModeLine(client);
 }
 
-static int
+static int _X_COLD
 SProcVidModeDeleteModeLine(ClientPtr client)
 {
     xXF86OldVidModeDeleteModeLineReq *oldstuff =
@@ -1821,7 +1825,7 @@ SProcVidModeDeleteModeLine(ClientPtr client)
     return ProcVidModeDeleteModeLine(client);
 }
 
-static int
+static int _X_COLD
 SProcVidModeModModeLine(ClientPtr client)
 {
     xXF86OldVidModeModModeLineReq *oldstuff =
@@ -1866,7 +1870,7 @@ SProcVidModeModModeLine(ClientPtr client)
     return ProcVidModeModModeLine(client);
 }
 
-static int
+static int _X_COLD
 SProcVidModeValidateModeLine(ClientPtr client)
 {
     xXF86OldVidModeValidateModeLineReq *oldstuff =
@@ -1911,7 +1915,7 @@ SProcVidModeValidateModeLine(ClientPtr client)
     return ProcVidModeValidateModeLine(client);
 }
 
-static int
+static int _X_COLD
 SProcVidModeSwitchMode(ClientPtr client)
 {
     REQUEST(xXF86VidModeSwitchModeReq);
@@ -1922,7 +1926,7 @@ SProcVidModeSwitchMode(ClientPtr client)
     return ProcVidModeSwitchMode(client);
 }
 
-static int
+static int _X_COLD
 SProcVidModeSwitchToMode(ClientPtr client)
 {
     REQUEST(xXF86VidModeSwitchToModeReq);
@@ -1932,7 +1936,7 @@ SProcVidModeSwitchToMode(ClientPtr client)
     return ProcVidModeSwitchToMode(client);
 }
 
-static int
+static int _X_COLD
 SProcVidModeLockModeSwitch(ClientPtr client)
 {
     REQUEST(xXF86VidModeLockModeSwitchReq);
@@ -1943,7 +1947,7 @@ SProcVidModeLockModeSwitch(ClientPtr client)
     return ProcVidModeLockModeSwitch(client);
 }
 
-static int
+static int _X_COLD
 SProcVidModeGetMonitor(ClientPtr client)
 {
     REQUEST(xXF86VidModeGetMonitorReq);
@@ -1953,7 +1957,7 @@ SProcVidModeGetMonitor(ClientPtr client)
     return ProcVidModeGetMonitor(client);
 }
 
-static int
+static int _X_COLD
 SProcVidModeGetViewPort(ClientPtr client)
 {
     REQUEST(xXF86VidModeGetViewPortReq);
@@ -1963,7 +1967,7 @@ SProcVidModeGetViewPort(ClientPtr client)
     return ProcVidModeGetViewPort(client);
 }
 
-static int
+static int _X_COLD
 SProcVidModeSetViewPort(ClientPtr client)
 {
     REQUEST(xXF86VidModeSetViewPortReq);
@@ -1975,7 +1979,7 @@ SProcVidModeSetViewPort(ClientPtr client)
     return ProcVidModeSetViewPort(client);
 }
 
-static int
+static int _X_COLD
 SProcVidModeGetDotClocks(ClientPtr client)
 {
     REQUEST(xXF86VidModeGetDotClocksReq);
@@ -1985,7 +1989,7 @@ SProcVidModeGetDotClocks(ClientPtr client)
     return ProcVidModeGetDotClocks(client);
 }
 
-static int
+static int _X_COLD
 SProcVidModeSetClientVersion(ClientPtr client)
 {
     REQUEST(xXF86VidModeSetClientVersionReq);
@@ -1996,7 +2000,7 @@ SProcVidModeSetClientVersion(ClientPtr client)
     return ProcVidModeSetClientVersion(client);
 }
 
-static int
+static int _X_COLD
 SProcVidModeSetGamma(ClientPtr client)
 {
     REQUEST(xXF86VidModeSetGammaReq);
@@ -2009,7 +2013,7 @@ SProcVidModeSetGamma(ClientPtr client)
     return ProcVidModeSetGamma(client);
 }
 
-static int
+static int _X_COLD
 SProcVidModeGetGamma(ClientPtr client)
 {
     REQUEST(xXF86VidModeGetGammaReq);
@@ -2019,7 +2023,7 @@ SProcVidModeGetGamma(ClientPtr client)
     return ProcVidModeGetGamma(client);
 }
 
-static int
+static int _X_COLD
 SProcVidModeSetGammaRamp(ClientPtr client)
 {
     int length;
@@ -2035,7 +2039,7 @@ SProcVidModeSetGammaRamp(ClientPtr client)
     return ProcVidModeSetGammaRamp(client);
 }
 
-static int
+static int _X_COLD
 SProcVidModeGetGammaRamp(ClientPtr client)
 {
     REQUEST(xXF86VidModeGetGammaRampReq);
@@ -2046,7 +2050,7 @@ SProcVidModeGetGammaRamp(ClientPtr client)
     return ProcVidModeGetGammaRamp(client);
 }
 
-static int
+static int _X_COLD
 SProcVidModeGetGammaRampSize(ClientPtr client)
 {
     REQUEST(xXF86VidModeGetGammaRampSizeReq);
@@ -2056,7 +2060,7 @@ SProcVidModeGetGammaRampSize(ClientPtr client)
     return ProcVidModeGetGammaRampSize(client);
 }
 
-static int
+static int _X_COLD
 SProcVidModeGetPermissions(ClientPtr client)
 {
     REQUEST(xXF86VidModeGetPermissionsReq);
@@ -2066,7 +2070,7 @@ SProcVidModeGetPermissions(ClientPtr client)
     return ProcVidModeGetPermissions(client);
 }
 
-static int
+static int _X_COLD
 SProcVidModeDispatch(ClientPtr client)
 {
     REQUEST(xReq);
