@@ -1,4 +1,4 @@
-/* A Bison parser, made by GNU Bison 3.7.5.  */
+/* A Bison parser, made by GNU Bison 3.8.2.  */
 
 /* Bison implementation for Yacc-like parsers in C
 
@@ -16,7 +16,7 @@
    GNU General Public License for more details.
 
    You should have received a copy of the GNU General Public License
-   along with this program.  If not, see <http://www.gnu.org/licenses/>.  */
+   along with this program.  If not, see <https://www.gnu.org/licenses/>.  */
 
 /* As a special exception, you may create a larger work that contains
    part or all of the Bison parser skeleton and distribute that work
@@ -46,10 +46,10 @@
    USER NAME SPACE" below.  */
 
 /* Identify Bison output, and Bison version.  */
-#define YYBISON 30705
+#define YYBISON 30802
 
 /* Bison version string.  */
-#define YYBISON_VERSION "3.7.5"
+#define YYBISON_VERSION "3.8.2"
 
 /* Skeleton name.  */
 #define YYSKELETON_NAME "yacc.c"
@@ -288,8 +288,10 @@ typedef union YYSTYPE YYSTYPE;
 
 extern YYSTYPE yylval;
 
+
 int yyparse (void);
 
+
 #endif /* !YY_YY_WINPREFSYACC_H_INCLUDED  */
 /* Symbol kind.  */
 enum yysymbol_kind_t
@@ -517,12 +519,18 @@ typedef int yy_state_fast_t;
 # define YY_USE(E) /* empty */
 #endif
 
-#if defined __GNUC__ && ! defined __ICC && 407 <= __GNUC__ * 100 + __GNUC_MINOR__
 /* Suppress an incorrect diagnostic about yylval being uninitialized.  */
-# define YY_IGNORE_MAYBE_UNINITIALIZED_BEGIN                            \
+#if defined __GNUC__ && ! defined __ICC && 406 <= __GNUC__ * 100 + __GNUC_MINOR__
+# if __GNUC__ * 100 + __GNUC_MINOR__ < 407
+#  define YY_IGNORE_MAYBE_UNINITIALIZED_BEGIN                           \
+    _Pragma ("GCC diagnostic push")                                     \
+    _Pragma ("GCC diagnostic ignored \"-Wuninitialized\"")
+# else
+#  define YY_IGNORE_MAYBE_UNINITIALIZED_BEGIN                           \
     _Pragma ("GCC diagnostic push")                                     \
     _Pragma ("GCC diagnostic ignored \"-Wuninitialized\"")              \
     _Pragma ("GCC diagnostic ignored \"-Wmaybe-uninitialized\"")
+# endif
 # define YY_IGNORE_MAYBE_UNINITIALIZED_END      \
     _Pragma ("GCC diagnostic pop")
 #else
@@ -739,7 +747,7 @@ static const yytype_int8 yytranslate[] =
 };
 
 #if YYDEBUG
-  /* YYRLINE[YYN] -- Source line where rule number YYN was defined.  */
+/* YYRLINE[YYN] -- Source line where rule number YYN was defined.  */
 static const yytype_uint8 yyrline[] =
 {
        0,   133,   133,   134,   137,   138,   142,   143,   146,   147,
@@ -784,18 +792,6 @@ yysymbol_name (yysymbol_kind_t yysymbol)
 }
 #endif
 
-#ifdef YYPRINT
-/* YYTOKNUM[NUM] -- (External) token number corresponding to the
-   (internal) symbol number NUM (which must be that of a token).  */
-static const yytype_int16 yytoknum[] =
-{
-       0,   256,   257,   258,   259,   260,   261,   262,   263,   264,
-     265,   266,   267,   268,   269,   270,   271,   272,   273,   274,
-     275,   276,   277,   278,   279,   280,   281,   282,   283,   284,
-     285,   286
-};
-#endif
-
 #define YYPACT_NINF (-47)
 
 #define yypact_value_is_default(Yyn) \
@@ -806,8 +802,8 @@ static const yytype_int16 yytoknum[] =
 #define yytable_value_is_error(Yyn) \
   0
 
-  /* YYPACT[STATE-NUM] -- Index in YYTABLE of the portion describing
-     STATE-NUM.  */
+/* YYPACT[STATE-NUM] -- Index in YYTABLE of the portion describing
+   STATE-NUM.  */
 static const yytype_int8 yypact[] =
 {
      -47,     7,   -47,   -47,    -1,     0,     1,    18,    29,    15,
@@ -825,9 +821,9 @@ static const yytype_int8 yypact[] =
      -47
 };
 
-  /* YYDEFACT[STATE-NUM] -- Default reduction number in state STATE-NUM.
-     Performed when YYTABLE does not specify something else to do.  Zero
-     means the default is an error.  */
+/* YYDEFACT[STATE-NUM] -- Default reduction number in state STATE-NUM.
+   Performed when YYTABLE does not specify something else to do.  Zero
+   means the default is an error.  */
 static const yytype_int8 yydefact[] =
 {
        2,     0,     1,     4,     0,     0,     0,     0,     0,     0,
@@ -845,7 +841,7 @@ static const yytype_int8 yydefact[] =
       58
 };
 
-  /* YYPGOTO[NTERM-NUM].  */
+/* YYPGOTO[NTERM-NUM].  */
 static const yytype_int8 yypgoto[] =
 {
      -47,   -47,   -47,   -46,   -47,   -47,   -47,   -47,   -47,   -47,
@@ -854,7 +850,7 @@ static const yytype_int8 yypgoto[] =
      -47,   -47,   -47
 };
 
-  /* YYDEFGOTO[NTERM-NUM].  */
+/* YYDEFGOTO[NTERM-NUM].  */
 static const yytype_int8 yydefgoto[] =
 {
        0,     1,    16,    56,    17,    18,    19,    20,    21,    22,
@@ -863,9 +859,9 @@ static const yytype_int8 yydefgoto[] =
       27,    28,    29
 };
 
-  /* YYTABLE[YYPACT[STATE-NUM]] -- What to do in state STATE-NUM.  If
-     positive, shift that token.  If negative, reduce the rule whose
-     number is the opposite.  If YYTABLE_NINF, syntax error.  */
+/* YYTABLE[YYPACT[STATE-NUM]] -- What to do in state STATE-NUM.  If
+   positive, shift that token.  If negative, reduce the rule whose
+   number is the opposite.  If YYTABLE_NINF, syntax error.  */
 static const yytype_int8 yytable[] =
 {
       57,    92,    69,    76,    77,    78,    79,     2,    60,    61,
@@ -894,8 +890,8 @@ static const yytype_int8 yycheck[] =
       31,    83,    66,   102,    -1,    -1,    -1,    -1,    89
 };
 
-  /* YYSTOS[STATE-NUM] -- The (internal number of the) accessing
-     symbol of state STATE-NUM.  */
+/* YYSTOS[STATE-NUM] -- The symbol kind of the accessing symbol of
+   state STATE-NUM.  */
 static const yytype_int8 yystos[] =
 {
        0,    33,     0,     3,     4,     7,     8,     9,    10,    18,
@@ -913,7 +909,7 @@ static const yytype_int8 yystos[] =
       35
 };
 
-  /* YYR1[YYN] -- Symbol number of symbol that rule YYN derives.  */
+/* YYR1[RULE-NUM] -- Symbol kind of the left-hand side of rule RULE-NUM.  */
 static const yytype_int8 yyr1[] =
 {
        0,    32,    33,    33,    34,    34,    35,    35,    36,    36,
@@ -925,7 +921,7 @@ static const yytype_int8 yyr1[] =
       59,    61,    60,    62,    63,    64
 };
 
-  /* YYR2[YYN] -- Number of symbols on the right hand side of rule YYN.  */
+/* YYR2[RULE-NUM] -- Number of symbols on the right-hand side of rule RULE-NUM.  */
 static const yytype_int8 yyr2[] =
 {
        0,     2,     0,     2,     1,     1,     0,     2,     1,     1,
@@ -946,6 +942,7 @@ enum { YYENOMEM = -2 };
 #define YYACCEPT        goto yyacceptlab
 #define YYABORT         goto yyabortlab
 #define YYERROR         goto yyerrorlab
+#define YYNOMEM         goto yyexhaustedlab
 
 
 #define YYRECOVERING()  (!!yyerrstatus)
@@ -986,10 +983,7 @@ do {                                            \
     YYFPRINTF Args;                             \
 } while (0)
 
-/* This macro is provided for backward compatibility. */
-# ifndef YY_LOCATION_PRINT
-#  define YY_LOCATION_PRINT(File, Loc) ((void) 0)
-# endif
+
 
 
 # define YY_SYMBOL_PRINT(Title, Kind, Value, Location)                    \
@@ -1016,10 +1010,6 @@ yy_symbol_value_print (FILE *yyo,
   YY_USE (yyoutput);
   if (!yyvaluep)
     return;
-# ifdef YYPRINT
-  if (yykind < YYNTOKENS)
-    YYPRINT (yyo, yytoknum[yykind], *yyvaluep);
-# endif
   YY_IGNORE_MAYBE_UNINITIALIZED_BEGIN
   YY_USE (yykind);
   YY_IGNORE_MAYBE_UNINITIALIZED_END
@@ -1204,6 +1194,7 @@ yyparse (void)
   YYDPRINTF ((stderr, "Starting parse\n"));
 
   yychar = YYEMPTY; /* Cause a token to be read.  */
+
   goto yysetstate;
 
 
@@ -1229,7 +1220,7 @@ yysetstate:
 
   if (yyss + yystacksize - 1 <= yyssp)
 #if !defined yyoverflow && !defined YYSTACK_RELOCATE
-    goto yyexhaustedlab;
+    YYNOMEM;
 #else
     {
       /* Get the current used size of the three stacks, in elements.  */
@@ -1257,7 +1248,7 @@ yysetstate:
 # else /* defined YYSTACK_RELOCATE */
       /* Extend the stack our own way.  */
       if (YYMAXDEPTH <= yystacksize)
-        goto yyexhaustedlab;
+        YYNOMEM;
       yystacksize *= 2;
       if (YYMAXDEPTH < yystacksize)
         yystacksize = YYMAXDEPTH;
@@ -1268,7 +1259,7 @@ yysetstate:
           YY_CAST (union yyalloc *,
                    YYSTACK_ALLOC (YY_CAST (YYSIZE_T, YYSTACK_BYTES (yystacksize))));
         if (! yyptr)
-          goto yyexhaustedlab;
+          YYNOMEM;
         YYSTACK_RELOCATE (yyss_alloc, yyss);
         YYSTACK_RELOCATE (yyvs_alloc, yyvs);
 #  undef YYSTACK_RELOCATE
@@ -1290,6 +1281,7 @@ yysetstate:
     }
 #endif /* !defined yyoverflow && !defined YYSTACK_RELOCATE */
 
+
   if (yystate == YYFINAL)
     YYACCEPT;
 
@@ -1404,233 +1396,233 @@ yyreduce:
   case 20: /* trayicon: TRAYICON STRING NEWLINE  */
 #line 160 "winprefsyacc.y"
                                         { SetTrayIcon((yyvsp[-1].sVal)); free((yyvsp[-1].sVal)); }
-#line 1408 "winprefsyacc.c"
+#line 1400 "winprefsyacc.c"
     break;
 
   case 21: /* rootmenu: ROOTMENU STRING NEWLINE  */
 #line 163 "winprefsyacc.y"
                                         { SetRootMenu((yyvsp[-1].sVal)); free((yyvsp[-1].sVal)); }
-#line 1414 "winprefsyacc.c"
+#line 1406 "winprefsyacc.c"
     break;
 
   case 22: /* defaultsysmenu: DEFAULTSYSMENU STRING atspot NEWLINE  */
 #line 166 "winprefsyacc.y"
                                                      { SetDefaultSysMenu((yyvsp[-2].sVal), (yyvsp[-1].iVal)); free((yyvsp[-2].sVal)); }
-#line 1420 "winprefsyacc.c"
+#line 1412 "winprefsyacc.c"
     break;
 
   case 23: /* defaulticon: DEFAULTICON STRING NEWLINE  */
 #line 169 "winprefsyacc.y"
                                            { SetDefaultIcon((yyvsp[-1].sVal)); free((yyvsp[-1].sVal)); }
-#line 1426 "winprefsyacc.c"
+#line 1418 "winprefsyacc.c"
     break;
 
   case 24: /* icondirectory: ICONDIRECTORY STRING NEWLINE  */
 #line 172 "winprefsyacc.y"
                                              { SetIconDirectory((yyvsp[-1].sVal)); free((yyvsp[-1].sVal)); }
-#line 1432 "winprefsyacc.c"
+#line 1424 "winprefsyacc.c"
     break;
 
   case 25: /* menuline: SEPARATOR NEWLINE newline_or_nada  */
 #line 175 "winprefsyacc.y"
                                                    { AddMenuLine("-", CMD_SEPARATOR, ""); }
-#line 1438 "winprefsyacc.c"
+#line 1430 "winprefsyacc.c"
     break;
 
   case 26: /* menuline: STRING ALWAYSONTOP NEWLINE newline_or_nada  */
 #line 176 "winprefsyacc.y"
                                                       { AddMenuLine((yyvsp[-3].sVal), CMD_ALWAYSONTOP, ""); free((yyvsp[-3].sVal)); }
-#line 1444 "winprefsyacc.c"
+#line 1436 "winprefsyacc.c"
     break;
 
   case 27: /* menuline: STRING EXEC STRING NEWLINE newline_or_nada  */
 #line 177 "winprefsyacc.y"
                                                       { AddMenuLine((yyvsp[-4].sVal), CMD_EXEC, (yyvsp[-2].sVal)); free((yyvsp[-4].sVal)); free((yyvsp[-2].sVal)); }
-#line 1450 "winprefsyacc.c"
+#line 1442 "winprefsyacc.c"
     break;
 
   case 28: /* menuline: STRING MENU STRING NEWLINE newline_or_nada  */
 #line 178 "winprefsyacc.y"
                                                       { AddMenuLine((yyvsp[-4].sVal), CMD_MENU, (yyvsp[-2].sVal)); free((yyvsp[-4].sVal)); free((yyvsp[-2].sVal)); }
-#line 1456 "winprefsyacc.c"
+#line 1448 "winprefsyacc.c"
     break;
 
   case 29: /* menuline: STRING RELOAD NEWLINE newline_or_nada  */
 #line 179 "winprefsyacc.y"
                                                  { AddMenuLine((yyvsp[-3].sVal), CMD_RELOAD, ""); free((yyvsp[-3].sVal)); }
-#line 1462 "winprefsyacc.c"
+#line 1454 "winprefsyacc.c"
     break;
 
   case 32: /* $@1: %empty  */
 #line 186 "winprefsyacc.y"
                        { OpenMenu((yyvsp[-1].sVal)); free((yyvsp[-1].sVal)); }
-#line 1468 "winprefsyacc.c"
+#line 1460 "winprefsyacc.c"
     break;
 
   case 33: /* menu: MENU STRING LB $@1 newline_or_nada menulist RB  */
 #line 186 "winprefsyacc.y"
                                                                                {CloseMenu();}
-#line 1474 "winprefsyacc.c"
+#line 1466 "winprefsyacc.c"
     break;
 
   case 34: /* iconline: STRING STRING NEWLINE newline_or_nada  */
 #line 189 "winprefsyacc.y"
                                                       { AddIconLine((yyvsp[-3].sVal), (yyvsp[-2].sVal)); free((yyvsp[-3].sVal)); free((yyvsp[-2].sVal)); }
-#line 1480 "winprefsyacc.c"
+#line 1472 "winprefsyacc.c"
     break;
 
   case 37: /* $@2: %empty  */
 #line 196 "winprefsyacc.y"
                  {OpenIcons();}
-#line 1486 "winprefsyacc.c"
+#line 1478 "winprefsyacc.c"
     break;
 
   case 38: /* icons: ICONS LB $@2 newline_or_nada iconlist RB  */
 #line 196 "winprefsyacc.y"
                                                             {CloseIcons();}
-#line 1492 "winprefsyacc.c"
+#line 1484 "winprefsyacc.c"
     break;
 
   case 39: /* group1: TOPMOST  */
 #line 199 "winprefsyacc.y"
                 { (yyval.uVal)=STYLE_TOPMOST; }
-#line 1498 "winprefsyacc.c"
+#line 1490 "winprefsyacc.c"
     break;
 
   case 40: /* group1: MAXIMIZE  */
 #line 200 "winprefsyacc.y"
                    { (yyval.uVal)=STYLE_MAXIMIZE; }
-#line 1504 "winprefsyacc.c"
+#line 1496 "winprefsyacc.c"
     break;
 
   case 41: /* group1: MINIMIZE  */
 #line 201 "winprefsyacc.y"
                    { (yyval.uVal)=STYLE_MINIMIZE; }
-#line 1510 "winprefsyacc.c"
+#line 1502 "winprefsyacc.c"
     break;
 
   case 42: /* group1: BOTTOM  */
 #line 202 "winprefsyacc.y"
                  { (yyval.uVal)=STYLE_BOTTOM; }
-#line 1516 "winprefsyacc.c"
+#line 1508 "winprefsyacc.c"
     break;
 
   case 43: /* group2: NOTITLE  */
 #line 205 "winprefsyacc.y"
                 { (yyval.uVal)=STYLE_NOTITLE; }
-#line 1522 "winprefsyacc.c"
+#line 1514 "winprefsyacc.c"
     break;
 
   case 44: /* group2: OUTLINE  */
 #line 206 "winprefsyacc.y"
                   { (yyval.uVal)=STYLE_OUTLINE; }
-#line 1528 "winprefsyacc.c"
+#line 1520 "winprefsyacc.c"
     break;
 
   case 45: /* group2: NOFRAME  */
 #line 207 "winprefsyacc.y"
                   { (yyval.uVal)=STYLE_NOFRAME; }
-#line 1534 "winprefsyacc.c"
+#line 1526 "winprefsyacc.c"
     break;
 
   case 46: /* stylecombo: group1  */
 #line 210 "winprefsyacc.y"
                        { (yyval.uVal)=(yyvsp[0].uVal); }
-#line 1540 "winprefsyacc.c"
+#line 1532 "winprefsyacc.c"
     break;
 
   case 47: /* stylecombo: group2  */
 #line 211 "winprefsyacc.y"
                  { (yyval.uVal)=(yyvsp[0].uVal); }
-#line 1546 "winprefsyacc.c"
+#line 1538 "winprefsyacc.c"
     break;
 
   case 48: /* stylecombo: group1 group2  */
 #line 212 "winprefsyacc.y"
                         { (yyval.uVal)=(yyvsp[-1].uVal)|(yyvsp[0].uVal); }
-#line 1552 "winprefsyacc.c"
+#line 1544 "winprefsyacc.c"
     break;
 
   case 49: /* stylecombo: group2 group1  */
 #line 213 "winprefsyacc.y"
                         { (yyval.uVal)=(yyvsp[-1].uVal)|(yyvsp[0].uVal); }
-#line 1558 "winprefsyacc.c"
+#line 1550 "winprefsyacc.c"
     break;
 
   case 50: /* styleline: STRING stylecombo NEWLINE newline_or_nada  */
 #line 216 "winprefsyacc.y"
                                                           { AddStyleLine((yyvsp[-3].sVal), (yyvsp[-2].uVal)); free((yyvsp[-3].sVal)); }
-#line 1564 "winprefsyacc.c"
+#line 1556 "winprefsyacc.c"
     break;
 
   case 53: /* $@3: %empty  */
 #line 223 "winprefsyacc.y"
                   {OpenStyles();}
-#line 1570 "winprefsyacc.c"
+#line 1562 "winprefsyacc.c"
     break;
 
   case 54: /* styles: STYLES LB $@3 newline_or_nada stylelist RB  */
 #line 223 "winprefsyacc.y"
                                                                {CloseStyles();}
-#line 1576 "winprefsyacc.c"
+#line 1568 "winprefsyacc.c"
     break;
 
   case 55: /* atspot: %empty  */
 #line 226 "winprefsyacc.y"
         { (yyval.iVal)=AT_END; }
-#line 1582 "winprefsyacc.c"
+#line 1574 "winprefsyacc.c"
     break;
 
   case 56: /* atspot: ATSTART  */
 #line 227 "winprefsyacc.y"
                   { (yyval.iVal)=AT_START; }
-#line 1588 "winprefsyacc.c"
+#line 1580 "winprefsyacc.c"
     break;
 
   case 57: /* atspot: ATEND  */
 #line 228 "winprefsyacc.y"
                 { (yyval.iVal)=AT_END; }
-#line 1594 "winprefsyacc.c"
+#line 1586 "winprefsyacc.c"
     break;
 
   case 58: /* sysmenuline: STRING STRING atspot NEWLINE newline_or_nada  */
 #line 231 "winprefsyacc.y"
                                                              { AddSysMenuLine((yyvsp[-4].sVal), (yyvsp[-3].sVal), (yyvsp[-2].iVal)); free((yyvsp[-4].sVal)); free((yyvsp[-3].sVal)); }
-#line 1600 "winprefsyacc.c"
+#line 1592 "winprefsyacc.c"
     break;
 
   case 61: /* $@4: %empty  */
 #line 238 "winprefsyacc.y"
                                    {OpenSysMenu();}
-#line 1606 "winprefsyacc.c"
+#line 1598 "winprefsyacc.c"
     break;
 
   case 62: /* sysmenu: SYSMENU LB NEWLINE $@4 newline_or_nada sysmenulist RB  */
 #line 238 "winprefsyacc.y"
                                                                                    {CloseSysMenu();}
-#line 1612 "winprefsyacc.c"
+#line 1604 "winprefsyacc.c"
     break;
 
   case 63: /* forceexit: FORCEEXIT NEWLINE  */
 #line 241 "winprefsyacc.y"
                                   { pref.fForceExit = TRUE; }
-#line 1618 "winprefsyacc.c"
+#line 1610 "winprefsyacc.c"
     break;
 
   case 64: /* silentexit: SILENTEXIT NEWLINE  */
 #line 244 "winprefsyacc.y"
                                    { pref.fSilentExit = TRUE; }
-#line 1624 "winprefsyacc.c"
+#line 1616 "winprefsyacc.c"
     break;
 
   case 65: /* debug: "DEBUG" STRING NEWLINE  */
 #line 247 "winprefsyacc.y"
                                    { ErrorF("LoadPreferences: %s\n", (yyvsp[-1].sVal)); free((yyvsp[-1].sVal)); }
-#line 1630 "winprefsyacc.c"
+#line 1622 "winprefsyacc.c"
     break;
 
 
-#line 1634 "winprefsyacc.c"
+#line 1626 "winprefsyacc.c"
 
       default: break;
     }
@@ -1712,6 +1704,7 @@ yyerrorlab:
      label yyerrorlab therefore never appears in user code.  */
   if (0)
     YYERROR;
+  ++yynerrs;
 
   /* Do not reclaim the symbols of the rule whose action triggered
      this YYERROR.  */
@@ -1772,7 +1765,7 @@ yyerrlab1:
 `-------------------------------------*/
 yyacceptlab:
   yyresult = 0;
-  goto yyreturn;
+  goto yyreturnlab;
 
 
 /*-----------------------------------.
@@ -1780,24 +1773,22 @@ yyacceptlab:
 `-----------------------------------*/
 yyabortlab:
   yyresult = 1;
-  goto yyreturn;
+  goto yyreturnlab;
 
 
-#if !defined yyoverflow
-/*-------------------------------------------------.
-| yyexhaustedlab -- memory exhaustion comes here.  |
-`-------------------------------------------------*/
+/*-----------------------------------------------------------.
+| yyexhaustedlab -- YYNOMEM (memory exhaustion) comes here.  |
+`-----------------------------------------------------------*/
 yyexhaustedlab:
   yyerror (YY_("memory exhausted"));
   yyresult = 2;
-  goto yyreturn;
-#endif
+  goto yyreturnlab;
 
 
-/*-------------------------------------------------------.
-| yyreturn -- parsing is finished, clean up and return.  |
-`-------------------------------------------------------*/
-yyreturn:
+/*----------------------------------------------------------.
+| yyreturnlab -- parsing is finished, clean up and return.  |
+`----------------------------------------------------------*/
+yyreturnlab:
   if (yychar != YYEMPTY)
     {
       /* Make sure we have latest lookahead translation.  See comments at
