@@ -42,9 +42,7 @@
 #include "winmsg.h"
 #include "winmonitors.h"
 #include "inputstr.h"
-#ifdef XWIN_CLIPBOARD
 #include "winclipboard/winclipboard.h"
-#endif
 
 /*
  * Global variables
@@ -145,7 +143,7 @@ winWindowProc(HWND hwnd, UINT message, WPARAM wParam, LPARAM lParam)
     case WM_DISPLAYCHANGE:
         /*
            WM_DISPLAYCHANGE seems to be sent when the monitor layout or
-           any monitor's resolution or depth changes, but it's lParam and
+           any monitor's resolution or depth changes, but its lParam and
            wParam always indicate the resolution and bpp for the primary
            monitor (so ignore that as we could be on any monitor...)
          */
@@ -153,7 +151,7 @@ winWindowProc(HWND hwnd, UINT message, WPARAM wParam, LPARAM lParam)
         /* We cannot handle a display mode change during initialization */
         if (s_pScreenInfo == NULL)
             FatalError("winWindowProc - WM_DISPLAYCHANGE - The display "
-                       "mode changed while we were intializing.  This is "
+                       "mode changed while we were initializing.  This is "
                        "very bad and unexpected.  Exiting.\n");
 
         /*
@@ -222,22 +220,13 @@ winWindowProc(HWND hwnd, UINT message, WPARAM wParam, LPARAM lParam)
                use RandR to resize the X screen
              */
             if ((!s_pScreenInfo->fUserGaveHeightAndWidth) &&
-                (s_pScreenInfo->iResizeMode == resizeWithRandr) && (FALSE
-#ifdef XWIN_MULTIWINDOWEXTWM
-                                                                    ||
-                                                                    s_pScreenInfo->
-                                                                    fMWExtWM
-#endif
-                                                                    ||
-                                                                    s_pScreenInfo->
+                (s_pScreenInfo->iResizeMode == resizeWithRandr) && (s_pScreenInfo->
                                                                     fRootless
-#ifdef XWIN_MULTIWINDOW
                                                                     ||
                                                                     s_pScreenInfo->
                                                                     fMultiWindow
-#endif
                 )) {
-                DWORD dwWidth, dwHeight;
+                DWORD dwWidth = 0, dwHeight = 0;
 
                 if (s_pScreenInfo->fMultipleMonitors) {
                     /* resize to new virtual desktop size */
@@ -249,7 +238,6 @@ winWindowProc(HWND hwnd, UINT message, WPARAM wParam, LPARAM lParam)
                     struct GetMonitorInfoData data;
 
                     if (QueryMonitor(s_pScreenInfo->iMonitor, &data)) {
-                        if (data.bMonitorSpecifiedExists == TRUE) {
                             dwWidth = data.monitorWidth;
                             dwHeight = data.monitorHeight;
                             /*
@@ -261,7 +249,6 @@ winWindowProc(HWND hwnd, UINT message, WPARAM wParam, LPARAM lParam)
                             ErrorF("Monitor number %d no longer exists!\n",
                                    s_pScreenInfo->iMonitor);
                         }
-                    }
                 }
 
                 /*
@@ -273,8 +260,9 @@ winWindowProc(HWND hwnd, UINT message, WPARAM wParam, LPARAM lParam)
                  */
 
                 /* Set screen size to match new size, if it is different to current */
-                if ((s_pScreenInfo->dwWidth != dwWidth) ||
-                    (s_pScreenInfo->dwHeight != dwHeight)) {
+                if (((dwWidth != 0) && (dwHeight != 0)) &&
+                    ((s_pScreenInfo->dwWidth != dwWidth) ||
+                     (s_pScreenInfo->dwHeight != dwHeight))) {
                     winDoRandRScreenSetSize(s_pScreen,
                                             dwWidth,
                                             dwHeight,
@@ -318,13 +306,8 @@ winWindowProc(HWND hwnd, UINT message, WPARAM wParam, LPARAM lParam)
         /* Break if we do not allow resizing */
         if ((s_pScreenInfo->iResizeMode == resizeNotAllowed)
             || !s_pScreenInfo->fDecoration
-#ifdef XWIN_MULTIWINDOWEXTWM
-            || s_pScreenInfo->fMWExtWM
-#endif
             || s_pScreenInfo->fRootless
-#ifdef XWIN_MULTIWINDOW
             || s_pScreenInfo->fMultiWindow
-#endif
             || s_pScreenInfo->fFullScreen)
             break;
 
@@ -621,13 +604,8 @@ winWindowProc(HWND hwnd, UINT message, WPARAM wParam, LPARAM lParam)
         if (s_pScreenInfo == NULL
             || (s_pScreenInfo->iResizeMode != resizeWithScrollbars)
             || s_pScreenInfo->fFullScreen || !s_pScreenInfo->fDecoration
-#ifdef XWIN_MULTIWINDOWEXTWM
-            || s_pScreenInfo->fMWExtWM
-#endif
             || s_pScreenInfo->fRootless
-#ifdef XWIN_MULTIWINDOW
             || s_pScreenInfo->fMultiWindow
-#endif
             )
             break;
 
@@ -806,22 +784,14 @@ winWindowProc(HWND hwnd, UINT message, WPARAM wParam, LPARAM lParam)
     case WM_LBUTTONDOWN:
         if (s_pScreenPriv == NULL || s_pScreenInfo->fIgnoreInput)
             break;
-        if (s_pScreenInfo->fRootless
-#ifdef XWIN_MULTIWINDOWEXTWM
-            || s_pScreenInfo->fMWExtWM
-#endif
-            )
+        if (s_pScreenInfo->fRootless)
             SetCapture(hwnd);
         return winMouseButtonsHandle(s_pScreen, ButtonPress, Button1, wParam);
 
     case WM_LBUTTONUP:
         if (s_pScreenPriv == NULL || s_pScreenInfo->fIgnoreInput)
             break;
-        if (s_pScreenInfo->fRootless
-#ifdef XWIN_MULTIWINDOWEXTWM
-            || s_pScreenInfo->fMWExtWM
-#endif
-            )
+        if (s_pScreenInfo->fRootless)
             ReleaseCapture();
         return winMouseButtonsHandle(s_pScreen, ButtonRelease, Button1, wParam);
 
@@ -829,22 +799,14 @@ winWindowProc(HWND hwnd, UINT message, WPARAM wParam, LPARAM lParam)
     case WM_MBUTTONDOWN:
         if (s_pScreenPriv == NULL || s_pScreenInfo->fIgnoreInput)
             break;
-        if (s_pScreenInfo->fRootless
-#ifdef XWIN_MULTIWINDOWEXTWM
-            || s_pScreenInfo->fMWExtWM
-#endif
-            )
+        if (s_pScreenInfo->fRootless)
             SetCapture(hwnd);
         return winMouseButtonsHandle(s_pScreen, ButtonPress, Button2, wParam);
 
     case WM_MBUTTONUP:
         if (s_pScreenPriv == NULL || s_pScreenInfo->fIgnoreInput)
             break;
-        if (s_pScreenInfo->fRootless
-#ifdef XWIN_MULTIWINDOWEXTWM
-            || s_pScreenInfo->fMWExtWM
-#endif
-            )
+        if (s_pScreenInfo->fRootless)
             ReleaseCapture();
         return winMouseButtonsHandle(s_pScreen, ButtonRelease, Button2, wParam);
 
@@ -852,22 +814,14 @@ winWindowProc(HWND hwnd, UINT message, WPARAM wParam, LPARAM lParam)
     case WM_RBUTTONDOWN:
         if (s_pScreenPriv == NULL || s_pScreenInfo->fIgnoreInput)
             break;
-        if (s_pScreenInfo->fRootless
-#ifdef XWIN_MULTIWINDOWEXTWM
-            || s_pScreenInfo->fMWExtWM
-#endif
-            )
+        if (s_pScreenInfo->fRootless)
             SetCapture(hwnd);
         return winMouseButtonsHandle(s_pScreen, ButtonPress, Button3, wParam);
 
     case WM_RBUTTONUP:
         if (s_pScreenPriv == NULL || s_pScreenInfo->fIgnoreInput)
             break;
-        if (s_pScreenInfo->fRootless
-#ifdef XWIN_MULTIWINDOWEXTWM
-            || s_pScreenInfo->fMWExtWM
-#endif
-            )
+        if (s_pScreenInfo->fRootless)
             ReleaseCapture();
         return winMouseButtonsHandle(s_pScreen, ButtonRelease, Button3, wParam);
 
@@ -875,22 +829,14 @@ winWindowProc(HWND hwnd, UINT message, WPARAM wParam, LPARAM lParam)
     case WM_XBUTTONDOWN:
         if (s_pScreenPriv == NULL || s_pScreenInfo->fIgnoreInput)
             break;
-        if (s_pScreenInfo->fRootless
-#ifdef XWIN_MULTIWINDOWEXTWM
-            || s_pScreenInfo->fMWExtWM
-#endif
-            )
+        if (s_pScreenInfo->fRootless)
             SetCapture(hwnd);
         return winMouseButtonsHandle(s_pScreen, ButtonPress, HIWORD(wParam) + 7,
                                      wParam);
     case WM_XBUTTONUP:
         if (s_pScreenPriv == NULL || s_pScreenInfo->fIgnoreInput)
             break;
-        if (s_pScreenInfo->fRootless
-#ifdef XWIN_MULTIWINDOWEXTWM
-            || s_pScreenInfo->fMWExtWM
-#endif
-            )
+        if (s_pScreenInfo->fRootless)
             ReleaseCapture();
         return winMouseButtonsHandle(s_pScreen, ButtonRelease,
                                      HIWORD(wParam) + 7, wParam);
@@ -1167,22 +1113,9 @@ winWindowProc(HWND hwnd, UINT message, WPARAM wParam, LPARAM lParam)
             ShowCursor(TRUE);
         }
 
-#ifdef XWIN_CLIPBOARD
-        /* Make sure the clipboard chain is ok. */
-        winFixClipboardChain();
-#endif
-
         /* Call engine specific screen activation/deactivation function */
         (*s_pScreenPriv->pwinActivateApp) (s_pScreen);
 
-#ifdef XWIN_MULTIWINDOWEXTWM
-        if (s_pScreenPriv->fActive) {
-            /* Restack all window unless using built-in wm. */
-            if (s_pScreenInfo->fMWExtWM)
-                winMWExtWMRestackWindows(s_pScreen);
-        }
-#endif
-
         return 0;
 
     case WM_COMMAND:
@@ -1192,7 +1125,6 @@ winWindowProc(HWND hwnd, UINT message, WPARAM wParam, LPARAM lParam)
             winDisplayExitDialog(s_pScreenPriv);
             return 0;
 
-#ifdef XWIN_MULTIWINDOW
         case ID_APP_HIDE_ROOT:
             if (s_pScreenPriv->fRootWindowShown)
                 ShowWindow(s_pScreenPriv->hwndScreen, SW_HIDE);
@@ -1200,13 +1132,10 @@ winWindowProc(HWND hwnd, UINT message, WPARAM wParam, LPARAM lParam)
                 ShowWindow(s_pScreenPriv->hwndScreen, SW_SHOW);
             s_pScreenPriv->fRootWindowShown = !s_pScreenPriv->fRootWindowShown;
             return 0;
-#endif
 
-#ifdef XWIN_CLIPBOARD
         case ID_APP_MONITOR_PRIMARY:
             fPrimarySelection = !fPrimarySelection;
             return 0;
-#endif
 
         case ID_APP_ABOUT:
             /* Display the About box */
@@ -1222,10 +1151,8 @@ winWindowProc(HWND hwnd, UINT message, WPARAM wParam, LPARAM lParam)
 
     case WM_GIVEUP:
         /* Tell X that we are giving up */
-#ifdef XWIN_MULTIWINDOW
         if (s_pScreenInfo->fMultiWindow)
             winDeinitMultiWindowWM();
-#endif
         GiveUp(0);
         return 0;
 
@@ -1243,7 +1170,7 @@ winWindowProc(HWND hwnd, UINT message, WPARAM wParam, LPARAM lParam)
         break;
 
     default:
-        if (message == s_uTaskbarRestart) {
+        if ((message == s_uTaskbarRestart) && !s_pScreenInfo->fNoTrayIcon)  {
             winInitNotifyIcon(s_pScreenPriv);
         }
         break;
