@@ -1,4 +1,3 @@
-/* $Xorg: opaque.h,v 1.4 2001/02/09 02:05:15 xorgcvs Exp $ */
 /*
 
 Copyright 1987, 1998  The Open Group
@@ -26,11 +25,6 @@ other dealings in this Software without prior written authorization
 from The Open Group.
 
 */
-/* $XFree86: xc/programs/Xserver/include/opaque.h,v 1.13 2003/07/24 13:50:25 eich Exp $ */
-
-#ifdef HAVE_DIX_CONFIG_H
-#include <dix-config.h>
-#endif
 
 #ifndef OPAQUE_H
 #define OPAQUE_H
@@ -39,49 +33,47 @@ from The Open Group.
 
 #include "globals.h"
 
-extern char *defaultTextFont;
-extern char *defaultCursorFont;
-extern int MaxClients;
-extern volatile char isItTimeToYield;
-extern volatile char dispatchException;
+extern _X_EXPORT int LimitClients;
+extern _X_EXPORT volatile char isItTimeToYield;
+extern _X_EXPORT volatile char dispatchException;
 
 /* bit values for dispatchException */
 #define DE_RESET     1
 #define DE_TERMINATE 2
-#define DE_PRIORITYCHANGE 4  /* set when a client's priority changes */
+#define DE_PRIORITYCHANGE 4     /* set when a client's priority changes */
 
-extern CARD32 TimeOutValue;
-extern int ScreenSaverBlanking;
-extern int ScreenSaverAllowExposures;
-extern int defaultScreenSaverBlanking;
-extern int defaultScreenSaverAllowExposures;
-extern int argcGlobal;
-extern char **argvGlobal;
-extern char *display;
+extern _X_EXPORT int ScreenSaverBlanking;
+extern _X_EXPORT int ScreenSaverAllowExposures;
+extern _X_EXPORT int defaultScreenSaverBlanking;
+extern _X_EXPORT int defaultScreenSaverAllowExposures;
+extern _X_EXPORT const char *display;
+extern _X_EXPORT int displayfd;
+extern _X_EXPORT Bool explicit_display;
+
+extern _X_EXPORT Bool disableBackingStore;
+extern _X_EXPORT Bool enableBackingStore;
+extern _X_EXPORT Bool enableIndirectGLX;
+extern _X_EXPORT Bool PartialNetwork;
+extern _X_EXPORT Bool RunFromSigStopParent;
 
-extern int defaultBackingStore;
-extern Bool disableBackingStore;
-extern Bool enableBackingStore;
-extern Bool disableSaveUnders;
-extern Bool PartialNetwork;
-#ifndef NOLOGOHACK
-extern int logoScreenSaver;
-#endif
 #ifdef RLIMIT_DATA
-extern int limitDataSpace;
+extern _X_EXPORT int limitDataSpace;
 #endif
 #ifdef RLIMIT_STACK
-extern int limitStackSpace;
+extern _X_EXPORT int limitStackSpace;
 #endif
 #ifdef RLIMIT_NOFILE
-extern int limitNoFile;
+extern _X_EXPORT int limitNoFile;
 #endif
-extern Bool permitOldBugs;
-extern Bool defeatAccessControl;
-extern long maxBigRequestSize;
-extern Bool blackRoot;
+extern _X_EXPORT Bool defeatAccessControl;
+extern _X_EXPORT long maxBigRequestSize;
+extern _X_EXPORT Bool party_like_its_1989;
+extern _X_EXPORT Bool whiteRoot;
+extern _X_EXPORT Bool bgNoneRoot;
 
-extern Bool CoreDump;
+extern _X_EXPORT Bool CoreDump;
+extern _X_EXPORT Bool NoListenAll;
 
+extern _X_EXPORT Bool AllowByteSwappedClients;
 
-#endif /* OPAQUE_H */
+#endif                          /* OPAQUE_H */
